@@ -12,6 +12,7 @@ except:
 from jinja2 import Template
 import json
 import os
+from aiges.utils.log import log
 from pprint import pprint
 
 SUB = "ase"
@@ -142,7 +143,8 @@ class Field(object):
 
     def _check_path(self, path):
         if not os.path.exists(path):
-            raise FileNotFoundError
+            e = FileNotFoundError
+            log.warn(e)
         return path
 
     def _encode(self, dataTye, encoding, binary):
@@ -707,9 +709,12 @@ class WrapperBase(metaclass=Metaclass):
             req.list = tmp
             # 3. 模拟调用 exec，并返回数据
             response = self.wrapperOnceExec(params, req)
+            if isinstance(response, Response):
+                log.info("success...")
+            else:
+                log.error("Please return Response instance in function wrapperOnceExec")
         except Exception as e:
             # 4. 模拟检查 wrapperOnceExec返回
             self.wrapperError(-1)
 
-
         # todo respData 检查
