@@ -23,6 +23,7 @@ try:
 except:
     from aiges.dto import Response, ResponseData, DataListNode, DataListCls
 
+import hashlib
 from aiges.sdk import WrapperBase, \
     StringParamField, \
     ImageBodyField, \
@@ -105,6 +106,12 @@ class Wrapper(WrapperBase):
 
     def wrapperOnceExec(cls, params: {}, reqData: DataListCls) -> Response:
         print("got reqdata , ", reqData.list)
+        #        print(type(reqData.list[0].data))
+        #        print(type(reqData.list[0].data))
+        #        print(reqData.list[0].len)
+
+        print(len(reqData.list[0].data))
+        print(hashlib.md5(reqData.list[0].data).hexdigest())
         print("I am infer logic...")
 
         r = Response()
